# Epic

This is a test project

## Installation

Run the following to install:

```python
pip install epic-by-tom-tkacz
```

## Usage

```python
from epic import say_epic

# Generate "Epic!"
say_epic()
```

# Developing Epic

To install epic, along with the tools you need to develop and run tests, run the following in your virtualenv:

```bash
$ pip install -e .[dev]
```